Pants
*****

Pants is a lightweight framework for writing asynchronous network applications
in Python. It is a simple, efficient and versatile networking solution which
makes no assumptions about your use-case, provides no superfluous features and
is very good-looking.

Pants is available under the
`Apache License, Version 2.0 <http://www.apache.org/licenses/LICENSE-2.0.html>`_

Install
=======

Pants can be obtained in several ways. You can use
`pip <http://pypi.python.org/pypi/pip>`_::

    pip install pants

Or `setuptools <http://pypi.python.org/pypi/setuptools>`_, if that's how you
roll::

    easy_install pants

Or for the bleeding edge version, you can clone the
`git <http://git-scm.com/>`_ repository::

    git clone git://github.com/ecdavis/pants

Pants requires `Python 2.6+ <http://python.org/>`_ - Python 3 is not yet supported.

Community
=========

Pants has a small but active community of developers who congregate in the IRC
channel `#pantsmud <http://webchat.freenode.net/?channels=pantsmud>`_ on
irc.freenode.net.

Documentation
=============

.. toctree::
    :maxdepth: 2

    overview
    guides/index
    examples/index
    benchmarks

API
===

.. toctree::
    :maxdepth: 2

    core/index
    utilities/index
    web/index
    contrib/index

